@@ -145,6 +145,7 @@ class _TransactionFactory(object):
         self._engine_cfg = {
             'sqlite_fk': _Default(False),
             'mysql_sql_mode': _Default('TRADITIONAL'),
+            'mysql_wsrep_sync_wait': _Default(),
             'mysql_enable_ndb': _Default(False),
             'connection_recycle_time': _Default(3600),
             'connection_debug': _Default(0),
@@ -163,7 +164,7 @@ class _TransactionFactory(object):
         }
         self._maker_cfg = {
             'expire_on_commit': _Default(False),
-            '__autocommit': True
+            '__autocommit': False,
         }
         self._transaction_ctx_cfg = {
             'rollback_reader_sessions': False,
@@ -218,6 +219,9 @@ class _TransactionFactory(object):
 
         :param mysql_sql_mode: MySQL SQL mode, defaults to TRADITIONAL
 
+        :param mysql_wsrep_sync_wait: MySQL wsrep_sync_wait, defaults to None,
+         which indicates no setting will be passed
+
         :param mysql_enable_ndb: enable MySQL Cluster (NDB) support
 
         :param connection_recycle_time: connection pool recycle time,
@@ -316,6 +320,14 @@ class _TransactionFactory(object):
         self._configure(False, kw)
 
     def _configure(self, as_defaults, kw):
+        if 'mysql_enable_ndb' in kw:
+            debtcollector.deprecate(
+                (
+                    'Support for the MySQL NDB Cluster storage engine has '
+                    'been deprecated and will be removed in a future release.'
+                ),
+                version='12.1.0',
+            )
 
         if self._started:
             raise AlreadyStartedError(
@@ -1236,9 +1248,13 @@ class LegacyEngineFacade(object):
 
     :keyword mysql_sql_mode: the SQL mode to be used for MySQL sessions.
                              (defaults to TRADITIONAL)
+    :keyword mysql_wsrep_sync_wait: value of wsrep_sync_wait for Galera
+                             (defaults to None, which indicates no setting
+                             will be passed)
     :keyword mysql_enable_ndb: If True, transparently enables support for
                                handling MySQL Cluster (NDB).
                                (defaults to False)
+                               **DEPRECATED**
     :keyword connection_recycle_time: Time period for connections to be
                             recycled upon checkout (defaults to 3600)
     :keyword connection_debug: verbosity of SQL debugging information.
@@ -1266,13 +1282,22 @@ class LegacyEngineFacade(object):
 
     """
     def __init__(self, sql_connection, slave_connection=None,
-                 sqlite_fk=False, autocommit=True,
+                 sqlite_fk=False, autocommit=False,
                  expire_on_commit=False, _conf=None, _factory=None, **kwargs):
         warnings.warn(
             "EngineFacade is deprecated; please use "
             "oslo_db.sqlalchemy.enginefacade",
             warning.OsloDBDeprecationWarning,
             stacklevel=2)
+
+        if autocommit is True:
+            warnings.warn(
+                'autocommit support will be removed in SQLAlchemy 2.0 and '
+                'should not be relied on; please rework your code to remove '
+                'reliance on this feature',
+                warning.OsloDBDeprecationWarning,
+                stacklevel=2)
+
         if _factory:
             self._factory = _factory
         else:
@@ -1346,7 +1371,7 @@ class LegacyEngineFacade(object):
 
     @classmethod
     def from_config(cls, conf,
-                    sqlite_fk=False, autocommit=True, expire_on_commit=False):
+                    sqlite_fk=False, autocommit=False, expire_on_commit=False):
         """Initialize EngineFacade using oslo.config config instance options.
 
         :param conf: oslo.config config instance
